exceptions
library
Exceptions / Errors
-
ConnectionException
-
Exception thrown when there is a connection error with the Redis server.
-
LockAcquisitionException
-
Exception thrown when a lock cannot be acquired in Redis.
-
OpenException
-
Exception thrown when there is an error opening a Redis connection or cache.
-
SecurityException
-
Exception thrown when there is a security-related error in Redis operations.
-
SocketException
-
Exception thrown when there is a socket-related error in Redis operations.