sameType<X extends Plug<X>> method

bool sameType<X extends Plug<X>>()
inherited

Checks if this plug is of the same type as another plug.

This method uses the generic type parameter to determine if two plugs are of the same type. It's useful for type checking and ensuring type safety when working with different plug implementations.

Implementation

bool sameType<X extends Plug<X>>() => T == X;